@@ -5,7 +5,7 @@ from mip import Model, xsum, minimize, BINARY
 from itertools import product
 import time
 
-import xml.etree.ElementTree as ET
+import xml.etree.ElementTree
 import re
 import geopy.distance
 import matplotlib.pyplot as plt
@@ -54,7 +54,7 @@ while True:
     try:
         namekml = input('Type the "name.kml" of the file:  ')
         # KML parse
-        tree = ET.parse(namekml)
+        tree = xml.etree.ElementTree.parse(namekml)
         root = tree.getroot()
     except FileNotFoundError:
         print('something went wrong! Try again.')
